<?php
/***********************************************************
*  Module       : Settings
*  Language     : ES Spanish
*  Version      : vt5.4.0
*  Created Date : 2008-01-18 17:46:07
*  Author       : JPL TSolucio, S.L.  -  rasomu
*  Last change  : 2012-02-28
*  Author       : Joe Bordes JPL TSolucio, S.L.
***********************************************************/

$mod_strings = array (
      'LBL_MODULE_NAME' => 'Configuración',
      'LBL_MODULE_TITLE' => 'Configuración: Inicio',
      'LBL_LIST_CONTACT_ROLE' => 'Rol',
      'LBL_LIST_LAST_NAME' => 'Apellidos',
      'LBL_FIRST_NAME' => 'Nombre:',
      'LBL_LAST_NAME' => 'Apellidos:',
      'LBL_PHONE' => 'Teléfono:',
      'LBL_EMAIL_ADDRESS' => 'Email',
      'LBL_TRANSCURR' => 'Cambiar la Moneda a',
      'LBL_CURRDEL' => 'Moneda para ser Borrada',
      'LBL_NEW_FORM_TITLE' => 'Nuevo Contacto',
      'LBL_NEW_CURRENCY' => 'Nueva Moneda',
      'LBL_VIEWING' => 'Mostrando',
      'LBL_CURRENCY_NAME' => 'Nombre de Moneda',
      'LBL_CURRENCY_CODE' => 'Código de Moneda',
      'LBL_CURRENCY_SYMBOL' => 'Símbolo',
      'LBL_CURRENCY_CRATE' => 'Ratio de Conversión',
      'LBL_CURRENCY_STATUS' => 'Estado',
      'LBL_CURRENCY_TOOL' => 'Herramientas',
      'LBL_CURRENCY_LIST' => 'Lista de Monedas',
      'NTC_DELETE_CONFIRMATION' => '¿Desea Borrar este registro?',
      'LEADCUSTOMFIELDS' => 'Campos Personalizados de Pre-Contactos',
      'ACCOUNTCUSTOMFIELDS' => 'Campos Personalizados de Cuentas',
      'CONTACTCUSTOMFIELDS' => 'Campos Personalizados de Contactos',
      'OPPORTUNITYCUSTOMFIELDS' => 'Campos Personalizados de Oportunidades',
      'HELPDESKCUSTOMFIELDS' => 'Campos Personalizados de Incidencias',
      'PRODUCTCUSTOMFIELDS' => 'Campos Personalizados de Productos',
      'VENDORCUSTOMFIELDS' => 'Campos Personalizados de Proveedores',
      'PRICEBOOKCUSTOMFIELDS' => 'Campos Personalizados de Tarifas',
      'POCUSTOMFIELDS' => 'Campos Personalizados de Ordenes de Compra',
      'SOCUSTOMFIELDS' => 'Campos Personalizados de Pedidos',
      'QUOTESCUSTOMFIELDS' => 'Campos Personalizados de Presupuestos',
      'INVOICECUSTOMFIELDS' => 'Campos Personalizados de Facturas',
      'EDITLEADPICKLISTVALUES' => 'Editar listas de Pre-Contactos',
      'EDITACCOUNTPICKLISTVALUES' => 'Editar listas de Cuentas',
      'EDITCONTACTPICKLISTVALUES' => 'Editar listas de Contactos',
      'EDITOPPORTUNITYPICKLISTVALUES' => 'Editar listas de Oportunidades',
      'EDITHELPDESKPICKLISTVALUES' => 'Editar listas de Incidencias ',
      'EDITPRODUCTPICKLISTVALUES' => 'Editar listas de Productos',
      'EDITEVENTPICKLISTVALUES' => 'Editar listas de Eventos',
      'EDITTASKPICKLISTVALUES' => 'Editar listas de Tareas',
      'EDITRSSPICKLISTVALUES' => 'Editar listas de Rss',
      'EDITVENDORPICKLISTVALUES' => 'Editar listas de Proveedores',
      'EDITPBPICKLISTVALUES' => 'Editar listas de Tarifas',
      'EDITPOPICKLISTVALUES' => 'Editar listas de Ordenes de Compra',
      'EDITSOPICKLISTVALUES' => 'Editar listas de Pedidos',
      'EDITQUOTEPICKLISTVALUES' => 'Editar listas de Presupuestos',
      'EDITINVOICEPICKLISTVALUES' => 'Editar listas de Facturas',
      'LBL_PICKLIST_FIELD_SETTINGS' => 'Configurar listados:',
      'Leads' => 'Pre-Contactos',
      'Accounts' => 'Cuentas',
      'Contacts' => 'Contactos',
      'Potentials' => 'Oportunidades',
      'HelpDesk' => 'Incidencias',
      'Products' => 'Productos',
      'Events' => 'Eventos',
      'Activities' => 'Tareas',
      'CustomFields' => 'Campos personalizados',
      'NewCustomField' => 'Nuevo Campo Personalizado',
      'NewCustomFieldAltC' => 'Nuevo Campo personalizado [Alt+c]:',
      'FieldName' => 'Nombre de Campo',
      'FieldType' => 'Tipo de Campo',
      'FieldLabel' => 'Etiqueta',
      'Delete' => 'Eliminar',
      'NEW' => 'Nuevo',
      'CUSTOMFIELD' => 'Campo Personalizado',
      'LBL_CUSTOM_FIELDS' => 'Campos Personalizados',
      'LBL_ADD_FIELD' => 'Añadir Campo',
      'LBL_CUSTM_MSG' => 'te permite ...',
      'PicklistFields' => ' Campos de lista',
      'Edit' => 'Editar',
      'LBL_EDIT_FIELD_TYPE' => 'Editar Tipo de Campo',
      'LBL_PROVIDE_FIELD_INFORMATION' => 'Proporcione información del campo: ',
      'LBL_SELECT_FIELD_TYPE' => 'Seleccionar tipo de campo: ',
      'LBL_PROVIDE_FIELD_DETAILS' => 'Proporcione detalles del campo: ',
      'LBL_LABEL' => 'Etiqueta: ',
      'LBL_LENGTH' => 'Extensión: ',
      'LBL_DECIMAL_PLACES' => 'Posiciones decimales: ',
      'LBL_PICK_LIST_VALUES' => 'Valores de la lista: ',
      'EditPickListValues' => 'Editar lista ',
      'LBL_FIELD_INFORMATION' => 'Valores del Campo:',
      'Values' => 'Valores',
      'EnterListOfValues' => 'Introduzca los valores para la lista. Un valor por línea.',
      'Text' => 'Texto',
      'Number' => 'Numero',
      'Percent' => 'Porcentaje',
      'Currency' => 'Moneda',
      'Date' => 'Fecha',
      'Email' => 'Email',
      'Phone' => 'Teléfono',
      'PickList' => 'Lista',
      'LBL_MULTISELECT_COMBO' => 'Lista de Multi-Selección',
      'Skype' => 'Skype',
      'Time'=>'Tiempo',
      'USERGROUPLIST' => 'Grupos',
      'EMAILTEMPLATES' => 'Plantillas de Email',
      'WORDINTEGRATION' => 'Plantillas de Mailing',
      'LBL_MAIL_MERGE' => 'Mailings',
      'NOTIFICATIONSCHEDULERS' => 'Programador de Notificaciones',
      'LBL_ACTIVE' => 'Activa',
      'LBL_INACTIVE' => 'Inactiva',
      'LBL_NOTIFICATION' => 'Notificación',
      'LBL_DESCRIPTION' => 'Descripción',
      'LBL_TOOL' => 'Herramienta',
      'LBL_EMAIL_CONFIG' => 'Configurar Servidor de Correo Saliente Email',
      'LBL_WORD_INTEGRATION' => 'Integración con MS Word:',
      'LBL_GROUP_SETTINGS' => 'Configurar Grupos:',
      'LBL_TEMPLATE_SETTINGS' => 'Configurar Plantillas:',
      'LBL_NOTIFICATION_SETTINGS' => 'Configurar las Notificaciones:',
      'LBL_EMAIL_SETTINGS' => 'Configurar Email:',
      'LBL_SECURITY_SETTINGS' => 'Configurar Seguridad:',
      'LBL_MAIL_SERVER_INFO' => 'Información del Servidor de Correo Saliente',
      'LBL_OUTGOING_MAIL_SERVER' => 'Servidor de Correo Saliente',
      'LBL_OUTGOING_MAIL_SERVER_LOGIN_USER_NAME' => 'Usuario de Servidor de Correo saliente',
      'LBL_OUTGOING_MAIL_SERVER_PASSWORD' => 'Contraseña Servidor de Correo saliente',
      'LBL_MAIL_SERVER_SMTP' => 'Servidor de Correo (SMTP)',
      'LBL_BACKUP_SERVER_CONFIG' => 'Configurar Servidor de backup',
      'LBL_SERVER_ADDRESS' => 'Dirección del Servidor',
      'LBL_FTP_SERVER_NAME' => 'Servidor ftp',
      'LBL_FTP_USER_NAME' => 'Usuario ftp',
      'LBL_FTP_PASSWORD' => 'Contraseña ftp',
      'LBL_FTP' => 'FTP',
      'LBL_SYSTEM_CONFIG' => 'Configuración del Sistema',
      'LBL_SYSTEM_INFO' => 'Información del Sistema',
      'LBL_PROXY_SETTINGS' => 'Configuración del Servidor Proxy',
      'LBL_AUDIT_TRAIL' => 'Auditoría de Usuarios',
      'LBL_ENABLE_AUDIT_TRAIL' => 'Activar Auditoría de Usuarios',
      'LBL_USER_AUDIT' => 'Seleccionar Usuario',
      'LBL_VIEW_AUDIT_TRAIL' => 'Ver Auditoría de Usuarios',
      'LBL_AUDIT_TRAIL_DESC' => 'Muestra los Usuarios que han accedido al CRM',
      'LBL_NO_DATA' => 'Sin Datos',
      'LBL_CURRENCY_CONFIGURATION' => '- Configurar Moneda',
      'LBL_CURRENCY_CONFIG' => 'Configurar Moneda',
      'LBL_CURRENCY_INFO' => 'Información de Moneda',
      'LBL_CURRENCY_TITLE' => 'Moneda',
      'LBL_CURRENCY_SETTINGS' => 'Configuración de Moneda',
      'LBL_USERNAME' => 'Usuario',
      'LBL_PASWRD' => 'Contraseña',
      'LBL_REQUIRES_AUTHENT' => '¿Requiere Autentificación?',
      'LBL_FROM_EMAIL_FIELD'=>'Email de',
      'LBL_USER_MANAGEMENT' => 'Administrar Usuarios',
      'LBL_USERS' => 'Usuarios',
      'LBL_USERS_LIST' => 'Lista de Usuarios',
      'LBL_GROUP_LIST' => 'Lista de Grupos',
      'LBL_CREATE_AND_MANAGE_USERS' => '- Crear y Administrar Usuarios (Administrador, Usuario estandar, etc.)',
      'LBL_CREATE_AND_MANAGE_USER_ROLES' => '- Crear y Administrar roles (Administrador, Usuario estandar, etc.)',
      'LBL_PROFILES' => 'Perfiles',
      'LBL_PROFILES_LIST' => 'Lista de Perfiles',
      'LBL_CREATE_AND_MANAGE_USER_PROFILES' => '- Crear y administrar perfiles de usuario (CEO, Ejecutivos de cuenta, etc.)',
      'LBL_CREATE_AND_MANAGE_USER_GROUPS' => '- Crear y administrar grupos de usuarios',
      'LBL_SHARING_ACCESS' => 'Privilegios de Acceso',
      'LBL_FIELDS_ACCESS' => 'Visibilidad de Campos',
      'LBL_DEFAULT_ORGANIZATION_FIELDS' => 'Configurar Acceso por defecto a los Campos',
      'LBL_SETTING_DEFAULT_ORGANIZATION_FIELDS' => ' - Configura los campos visibles por defecto en la organización',
      'LBL_SETTING_DEFAULT_SHARING_ACCESS' => '- Configura los Privilegios de acceso por defecto a los módulos en la organización',
      'LBL_FIELD_ACCESSIBILITY' => 'Configurar campos por perfil',
      'LBL_SETTING_FIELD_ACCESSIBILITY' => ' - Configura los campos visibles en cada perfil',
      'LBL_FIELD_ORDERING_DESC' => ' - Editar Posición de Campos',
      'LBL_FIELD_ORDERING' => 'Editar Bloques de Campos',
      'LBL_LEAD_FIELD_ACCESS' => 'Acceso a Campos de Pre-Contactos',
      'LBL_ACCOUNT_FIELD_ACCESS' => 'Acceso a Campos de Cuenta',
      'LBL_CONTACT_FIELD_ACCESS' => 'Acceso a Campos de Contactos',
      'LBL_OPPORTUNITY_FIELD_ACCESS' => 'Acceso a Campos de Oportunidades',
      'LBL_HELPDESK_FIELD_ACCESS' => 'Acceso a Campos de Incidencias',
      'LBL_PRODUCT_FIELD_ACCESS' => 'Acceso a Campos de Productos',
      'LBL_NOTE_FIELD_ACCESS' => 'Acceso a Campos de Documentos',
      'LBL_EMAIL_FIELD_ACCESS' => 'Acceso a Campos de Email',
      'LBL_TASK_FIELD_ACCESS' => 'Acceso a Campos de Tareas',
      'LBL_EVENT_FIELD_ACCESS' => 'Acceso a Campos de Eventos',
      'LBL_DELETE_DEMO_DATA' => 'Borrar datos de Ejemplo',
      'LBL_DELETE_DEMO_DATA_INFO' => '- Eliminar los datos de Ejemplo creados durante la instalación',
      'LBL_STUDIO' => 'Estudio',
      'LBL_CUSTOM_FIELD_SETTINGS' => 'Configurar Campos Personalizados',
      'LBL_CREATE_AND_MANAGE_USER_DEFINED_FIELDS' => '- Crear y administrar campos personalizados en los módulos',
      'LBL_SELECT_MODULE' => 'Seleccionar Módulo',
      'LBL_SELECT_CF_TEXT' => 'Seleccionar módulo para mostrar campos personalizados:',
      'LBL_PICKLIST_SETTINGS' => 'Configurar listados',
      'LBL_EDIT_PICKLIST_VALUES' => ' - Editar valores de listados',
      'LBL_EDIT' => 'Editando',
      'LBL_COMMUNICATION_TEMPLATES' => 'Plantillas de comunicación',
      'LBL_CREATE_EMAIL_TEMPLATES' => ' - Crear Plantillas de Email',
      'LBL_UPLOAD_MSWORD_TEMPLATES' => ' - Procesar plantillas de MS Word para Mailings',
      'LBL_SCHEDULE_EMAIL_NOTIFICATION' => ' - Programar notificaciones de Email',
      'LBL_EXPAND_CLOSE_MENU' => 'Expandir/Cerrar Menú',
      'LBL_CONFIGURATION' => 'Configuración',
      'LBL_CONFIGURE_MAIL_SERVER' => ' - Configurar Servidor de Correo',
      'LBL_BACKUP_SERVER_CONFIGURATION' => 'Configurar Servidor de Copias',
      'LBL_BACKUP_SERVER_INFO' => 'Información del Servidor de Copias',
      'LBL_BACKUP_SERVER_SETTINGS' => 'Configuraciones de Servidor de Copias',
      'LBL_CONFIGURE_BACKUP_SERVER' => ' - Configurar Servidor de Copias',
      'LBL_SYSTEM_CONFIGURATION' => ' - Configuración de sistema',
      'LBL_PROXY_SERVER_CONFIGURATION' => 'Confguración de Servidor Proxy',
      'LBL_PROXY_SERVER_INFO' => 'Información de Servidor Proxy',
      'LBL_PROXY_SERVER_SETTINGS' => 'Configuraciones de Servidor Proxy',
      'LBL_CONFIGURE_PROXY_SERVER' => ' - Configurar Servidor Proxy',
      'LBL_PROXY_PORT' => 'Número de Puerto',
      'LBL_URL' => 'URL',
      'LBL_CHECK_BOX' => 'Checkbox',
      'LBL_STANDARD_FIELDS' => 'Campos Estandar',
      'LBL_LEAD_SOURCE' => 'Origen de Pre-Contactos',
      'LBL_SALUTATION' => 'Saludo',
      'LBL_LEAD_STATUS' => 'Estado de Pre-Contactos',
      'LBL_INDUSTRY' => 'Actividad',
      'LBL_RATING' => 'Importancia',
      'LBL_ACCOUNT_TYPE' => 'Tipo de Cuenta',
      'LBL_BUSINESS_TYPE' => 'Tipo de Negocio',
      'LBL_CURRENCY_TYPE' => 'Tipo de Moneda',
      'LBL_SALES_STAGE' => 'Estado de Venta',
      'LBL_PRIORITY' => 'Prioridad',
      'LBL_STATUS' => 'Estado',
      'LBL_CATEGORY' => 'Categoría',
      'LBL_MANUFACTURER' => 'Fabricante',
      'LBL_PRODUCT_CATEGORY' => 'Categoría de Producto',
      'LBL_RSS_CATEGORY' => 'Categoría RSS',
      'LBL_ADD_MAIL_ACCOUNT' => 'Añadir Cuenta de correo',
      'LBL_NEW_MAIL_ACCOUNT_TITLE' => 'Nueva Cuenta de Correo [Alt+M]',
      'LBL_NEW_MAIL_ACCOUNT_KEY' => 'M',
      'LBL_NEW_MAIL_ACCOUNT_LABEL' => 'Nueva Cuenta de Correo ',
      'LBL_GENERAL_INFO' => 'Información General',
      'LBL_DISPLAY_NAME' => 'Mostrar Nombre',
      'LBL_MAIL_PROTOCOL' => 'Protocolo del Correo',
      'LBL_LIST_PASSWORD' => 'Contraseña',
      'LBL_MAIL_SERVER_NAME' => 'Nombre del Servidor de Correo',
      'LBL_MAIL_SERVER_SETTINGS' => 'Configuración del Servidor de Correo',
      'LBL_INCOME_SERVER_SETTINGS' => 'Servidor Entrante',
      'LBL_TEST_SETTINGS' => 'Probar la configuración de mi cuenta',
      'LBL_TEST_BUTTON_TITLE' => 'Probar mi cuenta ahora [Alt+T]',
      'LBL_TEST_BUTTON_KEY' => 'T',
      'LBL_TEST_BUTTON_LABEL' => 'Probar mi cuenta',
      'LBL_DEFAULT' => 'Por Defecto',
      'LBL_IMAP2' => 'IMAP2',
      'LBL_IMAP4' => 'IMAP4',
      'LBL_POP' => 'POP',
      'LBL_IMAP' => 'IMAP',
      'LBL_MAIL_DISCLAIM' => 'Los elementos marcados con <font color="red">*</font> son obligatorios<br>Los elementos marcados con <font color="red">* *</font> no están completamente soportados',
      'LBL_SSL_OPTIONS' => 'Opciones SSL',
      'LBL_TLS' => 'TLS',
      'LBL_NO_TLS' => 'Sin TLS',
      'LBL_CERT_VAL' => 'Validaciones de Certificado',
      'LBL_INT_MAILER' => '¿Usar Mailer Interno?',
      'LBL_INT_MAILER_USE' => 'Si',
      'LBL_INT_MAILER_NOUSE' => 'No',
      'LBL_VAL_SSL_CERT' => 'Validar Certificado SSL',
      'LBL_DONOT_VAL_SSL_CERT' => 'No Validar Certificado SSL',
      'LBL_WEB_MAIL_CONFIG' => 'Configuración de Email',
      'LBL_CONFIGURE_WEB_MAIL' => ' - Configurar el Web Mail',
      'LBL_LIST_MAIL_ACCOUNT' => 'Lista de Cuentas de Correo',
      'LBL_USAGEUNIT' => 'Unidad de Uso',
      'LBL_GLACCT' => 'Cuenta contable',
      'LBL_QUOTE_STAGE' => 'Fase del Presupuesto',
      'LBL_CARRIER' => 'Transportista',
      'LBL_TAXCLASS' => 'Tipo de Impuesto',
      'LBL_MY_DETAILS' => 'Mis Detalles',
      'LBL_MY_MAIL_SERVER_DET' => 'Detalles de mi Servidor de Correo',
      'LBL_EMAIL_ID' => 'Email ID',
      'LBL_NAME_EXAMPLE' => '(Ejemplo : Juan García)',
      'LBL_EMAIL_EXAMPLE' => '(Ejemplo : Juan_Garcia@suemail.com)',
      'LBL_REFRESH_TIMEOUT' => 'Timeout de Refresco',
      'LBL_1_MIN' => '1 minuto',
      'LBL_2_MIN' => '2 minutos',
      'LBL_3_MIN' => '3 minutos',
      'LBL_4_MIN' => '4 minutos',
      'LBL_5_MIN' => '5 minutos',
      'LBL_EMAILS_PER_PAGE' => 'Emails por Página',
      'LBL_ORGANIZATION_NAME' => 'Nombre de la Empresa',
      'LBL_ORGANIZATION_ADDRESS' => 'Dirección',
      'LBL_ORGANIZATION_CITY' => 'Población',
      'LBL_ORGANIZATION_STATE' => 'Provincia',
      'LBL_ORGANIZATION_CODE' => 'Código Postal',
      'LBL_ORGANIZATION_COUNTRY' => 'País',
      'LBL_ORGANIZATION_PHONE' => 'Teléfono',
      'LBL_ORGANIZATION_FAX' => 'Fax',
      'LBL_ORGANIZATION_WEBSITE' => 'Página Web',
      'LBL_ORGANIZATION_DETAILS' => 'Información de la Empresa',
      'LBL_SPECIFY_COMPANY_DETAILS' => ' - Especifique la Información de la Empresa',
      'LBL_ORGANIZATION_LOGO' => 'Nombre del Logo',
      'LBL_UPLOAD' => 'Adjuntar',
      'LBL_FILENAME' => 'Nombre del Fichero',
      'LBL_SETTINGS' => 'Configuración',
      'LBL_COMPANY_DETAILS' => 'Información de la Empresa',
      'LBL_SEVERITY' => 'Urgencia',
      'LBL_FAQ_CATEGORY' => 'Categoría de la FAQ',
      'LBL_VENDOR_FIELD_ACCESS' => 'Acceso a campos de Proveedores',
      'LBL_PB_FIELD_ACCESS' => 'Acceso a campos de Tarifas',
      'LBL_QUOTE_FIELD_ACCESS' => 'Acceso a campos de Presupuestos',
      'LBL_PO_FIELD_ACCESS' => 'Acceso a campos de Ordenes de Compra',
      'LBL_SO_FIELD_ACCESS' => 'Acceso a campos de Pedidos',
      'LBL_INVOICE_FIELD_ACCESS' => 'Acceso a campos de Facturas',
      'INVENTORYNOTIFICATION' => 'Notificaciones de Inventario',
      'LBL_INVENTORY_NOTIFICATIONS' => ' - Configurar los avisos de Inventario',
      'INVENTORYTERMSANDCONDITIONS' => 'Inventario: Condiciones Generales',
      'LBL_INVENTORY_TERMSANDCONDITIONS' => ' - Editar Condiciones Generales de Inventario',
      'LBL_TANDC_TEXT' => 'Texto de Condiciones Generales',
      'LBL_INVENTORY_TANDC' => 'Inventario - Condiciones Generales',
      'LBL_OTHER_SETTINGS' => 'Otras Configuraciones',
      'LBL_SCROLL' => '[Arriba]',
      'LBL_INV_NOT_DESC' => 'Lo que sigue, es la lista de las notificaciones que se envían al proveedor del producto con respecto a la demanda y a la cantidad actual disponibles durante la creación de un Presupuesto, de un Pedido y de una Facturación.',
      'InvoiceNotification' => 'Stock de producto al generar una factura',
      'InvoiceNotificationDescription' => 'Cuando el nivel del Stock del producto es inferior al nivel del reordenar, la notificación será enviada al proveedor del producto. ',
      'Vendor' => 'Proveedores',
      'PriceBook' => 'Tarifas',
      'Quotes' => 'Presupuestos',
      'PurchaseOrder' => 'Ordenes de Compra',
      'SalesOrder' => 'Ordenes de Venta',
      'Invoice' => 'Facturas',
      'LBL_LEAD_MAP_CUSTOM_FIELD' => 'Crear correspondencia de campos personalizados',
      'leadCustomFieldDescription' => 'Crear correspondencias entre un campo personalizado de los Pre-Contactos y otro de Contacto',
      'LBL_MAPPING_INFO' => 'Información de correspondencias',
      'LBL_ACCOUNT_FIELD' => 'Campo Personalizado de Cuentas',
      'LBL_CONTACT_FIELD' => 'Campo Personalizado de Contacto',
      'LBL_POTENTIAL_FIELD' => 'Campo Personalizado de Oportunidad',
      'CUSTOMFIELDMAPPING' => 'Correspondencia de campos personalizados',
      'LBL_FIELD_MAPPING' => 'Correspondencia de campos',
      'LBL_LEAD_FIELD' => 'Campo Personalizado de Pre-Contactos',
      'LBL_TEXT_AREA' => 'Area de Texto',
      'NOTESCUSTOMFIELDS' => 'Campo Personalizado de Documentos',
      'LBL_ASSIGN_MODULE_OWNERS' => 'Asignar Propietarios de Módulos',
      'LBL_MODULE_OWNERS' => 'Propietarios de Módulos',
      'LBL_ASSIGN_MODULE_OWNERS_INFO' => ' - Asignar Propietarios para cada Módulo',
      'LBL_MODULE' => 'Módulo',
      'LBL_OWNER' => 'Propietario',
      'LBL_MIGRATION' => 'Migrar desde una Versión Anterior',
      'LBL_MIGRATION_INFO' => ' - Migrar desde una Versión Anterior de vTiger',
      'LBL_USER_DESCRIPTION' => 'Gestionar Usuarios que acceden al CRM',
      'LBL_ROLE_DESCRIPTION' => 'Definir Jerarquía de Roles y Asignar a Usuarios',
      'LBL_PROFILE_DESCRIPTION' => 'Definir Perfiles para asignar derechos de acceso a cada Rol',
      'LBL_GROUP_DESCRIPTION' => 'Definir Grupos basados en roles, usuarios, perfiles...',
      'LBL_SHARING_ACCESS_DESCRIPTION' => 'Definir y Personalizar Niveles de Acceso en la Organización ',
      'LBL_SHARING_FIELDS_DESCRIPTION' => 'Mostrar u Ocultar Campos en cada Módulo del CRM',
      'LBL_MODULE_OWNERS_DESCRIPTION' => 'Asignar Propietarios a cada Módulo del CRM',
      'LBL_ANNOUNCEMENT_DESCRIPTION' => 'Configurar Anuncio',
      'LBL_CUSTOM_FIELDS_DESCRIPTION' => 'Crear y Gestionar Campos Personalizados',
      'LBL_PICKLIST_DESCRIPTION' => 'Gestionar Listados de los Módulos del CRM',
      'LBL_EMAIL_TEMPLATE_DESCRIPTION' => 'Gestionar Plantillas de Email',
      'LBL_MAIL_MERGE_DESCRIPTION' => 'Gestionar Plantillas para Mailings',
      'LBL_NOTIF_SCHED_DESCRIPTION' => 'Administre las notificaciones que le alertarán en caso de eventos importantes',
      'LBL_INV_NOTIF_DESCRIPTION' => 'Cambiar Configuración de las Alertas relacionadas con el Inventario',
      'LBL_INV_TANDC_DESCRIPTION' => 'Gestionar los Textos de las Condiciones Generales',
      'LBL_COMPANY_DESCRIPTION' => 'Gestionar información de su Empresa',
      'LBL_MAIL_SERVER_DESCRIPTION' => 'Editar Configuración del Servidor de Correo Saliente',
      'LBL_BACKUP_SERVER_DESCRIPTION' => 'Editar Configuración del Servidor de Backup',
      'LBL_CURRENCY_DESCRIPTION' => 'Gestionar Monedas y Valores de Cambio Monetario',
      'LBL_TAX_DESCRIPTION' => 'Gestionar Impuestos',
      'LBL_SYSTEM_DESCRIPTION' => 'Mostrar Configuración del Sistema',
      'LBL_PROXY_DESCRIPTION' => 'Editar Configuración de Proxy',
      'LBL_AUDIT_DESCRIPTION' => 'Mostrar Configuración de Auditoría',
      'LBL_TAX_DESC' => 'Gestionar IVA y Otros Impuestos',
      'LBL_COMPANY_DESC' => 'Información y Contacto de su Empresa',
      'LBL_SELECT_LOGO' => 'Seleccionar Logotipo :',
      'LBL_INVEN_TANDC_DESC' => 'Cambiar el texto que aparece en la sección Condiciones generales de los  módulos de Presupuestos, Pedidos y Facturación',
      'LBL_MAIL_SERVER_DESC' => 'Gestionar la configuración del Servidor de Correo',
      'LBL_BACKUP_SERVER_DESC' => 'Gestionar la configuración del Servidor de Backup',
      'LBL_MODULES_AND_OWNERS' => 'Módulos y Propietarios',
      'LBL_GROUP_DESC' => 'Gestionar Grupos de Usuarios',
      'LBL_MAIL_MERGE_DESC' => 'Gestionar las Plantillas de Mailing usadas en los Módulos del CRM',
      'LBL_REQUIRE_SMTP_AUTHENTICATION' => '¿Es necesaria la Autentificación SMTP?',
      'LBL_ANNOUNCEMENT' => 'Anuncios',
      'LBL_SETTING_ANNOUNCEMENT' => 'Anuncio',
      'LBL_ANNOUNCE_TEXT' => 'Texto de Anuncio',
      'LBL_UPDATE_BUTTON' => 'Actualizar',
      'LBL_ANNOUNCEMENT_INFO' => 'Escriba el texto del anuncio y pulse el botón de actualizar.',
      'LBL_ANNOUNCEMENT_DESC' => 'Modificar el texto de los anuncios que aparecen en la parte superior de la página',
      'LBL_EMAIL_CONTENTS' => 'Contenidos del Email',
      'LBL_SUBJECT' => 'Asunto',
      'LBL_MESSAGE' => 'Mensaje',
      'LBL_PICKLIST_EDITOR' => 'Editor de Listas Desplegables',
      'LBL_PICKLIST_AVAIL' => 'Listados disponibles en',
      'LBL_PICKLIST_AVAILINFO1' => 'Los listados disponibles en',
      'LBL_PICKLIST_AVAILINFO2' => 'se muestran abajo. Pulse Editar para modificar el contenido de la lista.',
      'LBL_EDIT_PICKLIST' => 'Editar campos de listados',
      'LBL_PICKLIST_SAVEINFO' => 'Introduzca las entradas una encima de otra y pulse el botón de guardar.',
      'LBL_SELECT_CRM_MODULE' => 'Seleccionar módulo del CRM',
      'LBL_TAX_SETTINGS' => 'Configuración de Impuestos',
      'LBL_INVENTORY_TAX_CONFIG' => 'Configuración de Impuestos en Inventario',
      'LBL_CUSTOM_MAPP_INFO' => 'Solamente el módulo de Pre-Contactos permite la vinculación de campos con otros Módulos.',
      'LBL_MAPPING_OTHER_MODULES' => 'Vinculación con otros Módulos',
      'LBL_CUSTOM_FILED_IN' => 'Campos Personalizados en ',
      'LBL_ROLE_HIERARCHY_TREE' => 'Arbol de Roles y Jerarquía',
      'LBL_EDIT_FIELD_MAPPING' => 'Editando vínculos entre Campos',
      'LBL_LOGIN_HISTORY_DETAILS' => 'Histórico de Accesos',
      'LBL_LOGIN_HISTORY_DESCRIPTION' => 'Muestra el Histórico de Accesos de todos los Usuarios',
      'LBL_NON_EDITABLE_PICKLIST_ENTRIES' => 'Entradas no-editables de Listas de Selección',
      'LBL_PRODUCT_TAX_SETTINGS' => 'Productos',
      'LBL_SHIPPING_HANDLING_TAX_SETTINGS' => 'Transporte y Manipulado',
      'LBL_PROXY_SERVER_DESC' => 'Configurar proxy para acceder a RSS de Internet',
      'LBL_NEW_CURRENCTY' => 'Nueva Moneda',
      'LBL_BASE_CURRENCY' => 'Moneda Principal ',
      'LBL_DELETE_CURRENCY' => 'Borrar Moneda',
      'LBL_DEFAULT_DETAIL_VIEW' => 'Vista Predeterminada',
      'LBL_DEFAULT_MODULE_VIEW' => 'Vista Predeterminada de Módulos',
      'LBL_DEFAULT_MODULE_VIEW_DESC' => 'Establecer Vista Predeterminada para todos los módulos',
      'LBL_ENABLE_SINGLEPANE_VIEW' => 'Activar Vista sin Pestañas',
      'LBL_CLEAR_DATA' => 'Borrar Datos',
      'LBL_ENABLE' => 'Activar',
      'LBL_FAQ_FIELD_ACCESS' => 'Acceso a Campos de FAQ',
      'LBL_ADD_TAX_BUTTON' => 'Añadir Impuesto',
      'LBL_NO_TAXES_AVAILABLE' => 'No hay Impuestos Disponibles',
      'LBL_PLEASE' => 'Por Favor',
      'LBL_ROLES' => 'Roles',
      'LBL_CREATE_NEW_ROLE' => 'Crear Nuevo Rol',
      'LBL_PROPERTIES' => 'Propiedades de',
      'LBL_NEW_ROLE' => 'Nuevo Rol',
      'LBL_ROLE_NAME' => 'Nombre del Rol',
      'LBL_REPORTS_TO' => 'Informa a',
      'LBL_PROFILE_M' => 'Perfil',
      'LBL_PROFILES_AVLBL' => 'Perfiles Disponibles',
      'LBL_ASSIGN_PROFILES' => 'Perfiles Asignados',
      'LBL_MEMBER' => 'Miembros',
      'LBL_DELETE_ROLE' => 'Borrar Rol',
      'LBL_ROLE_TO_BE_DELETED' => ' Rol para Borrar',
      'LBL_TRANSFER_USER_ROLE' => 'Transferir Usuarios a Rol',
      'LBL_ASSOCIATED_PROFILES' => 'Perfiles Asociados :',
      'LBL_ASSOCIATED_USERS' => 'Usuarios Asociados :',
      'LBL_EMAIL_TEMPLATES' => 'Plantillas de Email',
      'LBL_EMAIL_TEMPLATE_DESC' => 'Gestionar plantillas de Email usadas para Campañas y Mailings',
      'LBL_LIST_SELECT' => 'Seleccionar',
      'LBL_EMAIL_TEMPLATE' => 'Plantilla de Email',
      'LBL_TEMPLATE_TOOLS' => 'Herramientas',
      'LBL_NEW_TEMPLATE' => 'Nueva Plantilla',
      'LBL_FOLDER' => 'Carpeta',
      'LBL_NAME' => 'Nombre',
      'LBL_PERSONAL' => 'Personal',
      'LBL_PUBLIC' => 'Publico',
      'LBL_ACCOUNT_FIELDS' => 'Campos de Cuenta',
      'LBL_CONTACT_FIELDS' => 'Campos de Contacto',
      'LBL_LEAD_FIELDS' => 'Campos de Pre-Contacto',
      'LBL_USER_FIELDS' => 'Campos de Usuario',
      'LNK_SAMPLE_EMAIL' => 'Ver Email de ejemplo',
      'LBL_TEMPLATE_FILE' => 'Archivo de plantilla',
      'LBL_MODULENAMES' => 'Módulo',
      'LBL_DOWNLOAD' => 'Descarga',
      'LBL_ADD_TEMPLATE' => 'Añadir Plantilla',
      'LBL_WORD_TEMPLATES' => 'Plantillas de Mailing',
      'LBL_TASK_NOTIFICATION' => 'Tarea Retrasada',
      'LBL_BIG_DEAL' => 'Gran Negocio',
      'LBL_PENDING_TICKETS' => 'Tickets Pendientes',
      'LBL_MANY_TICKETS' => 'Demasiados Tickets',
      'LBL_START_NOTIFICATION' => 'Inicio de Soporte',
      'LBL_ACTIVITY_NOTIFICATION' => 'Evento',
      'LBL_TASK_NOTIFICATION_DESCRITPION' => 'Notificar si una tarea se retrasa más de 24 hrs',
      'LBL_BIG_DEAL_DESCRIPTION' => 'Notificar si se cierra un gran Negocio',
      'LBL_TICKETS_DESCRIPTION' => 'Notifica que existen partes en estado pendiente',
      'LBL_MANY_TICKETS_DESCRIPTION' => 'Notificar si alguien tiene demasiados tickets, pudiendo afectar a la calidad del servicio',
      'LBL_START_DESCRIPTION' => 'Notifica que se inicia el periodo de soporte contratado',
      'LBL_ACTIVITY_REMINDER_DESCRIPTION' => 'Notificar los Eventos basándose en la configuración de Recordatorios',
      'QuoteNotificationDescription' => 'Cuando se genera un Presupuesto, si el Stock del producto almacenado es menor a la cantidad presupuestada se envía un aviso al responsable del producto.',
      'SalesOrderNotificationDescription' => 'Cuando se genera una Orden de Venta, si el Stock del producto almacenado es menor a la cantidad pedida se envía un aviso al responsable del producto.',
      'Tools' => 'Herramientas',
      'QuoteNotification' => 'Notificación de stock de producto bajo durante la generación de un presupuesto',
      'SalesOrderNotification' => 'Notificación de stock de producto bajo durante la generación de una Orden de Venta',
      'LBL_NOTE_DO_NOT_REMOVE_INFO' => 'Nota:  No quite ni altere los valores dentro de {  }',
      'LBL_TOTAL' => 'Total :',
      'LBL_NEW_PROFILE' => 'Nuevo Perfil',
      'LBL_LIST_NO' => '#',
      'LBL_NEW_PROFILE_NAME' => 'Nombre de Perfil',
      'LBL_LIST_TOOLS' => 'Herramientas',
      'LBL_PROFILE_MESG' => 'Viendo Privilegios de acceso para',
      'LBL_PROFILE_PRIVILEGES' => 'Privilegios de perfil',
      'LBL_DEFINE_PRIV_FOR' => ' Definir privilegios para ',
      'LBL_USE_OPTION_TO_SET_PRIV' => 'Use las opciones de abajo para determinar los privilegios',
      'LBL_SUPER_USER_PRIV' => 'Privilegios Globales',
      'LBL_SET_PRIV_FOR_EACH_MODULE' => 'Establecer Privilegios para cada módulo',
      'LBL_FIELDS_AND_TOOLS_SETTINGS' => 'Configuración de campos y herramientas',
      'LBL_VIEW_ALL' => 'Ver todo',
      'LBL_EDIT_ALL' => 'Usar todo',
      'LBL_ALLOW' => 'Permitir',
      'LBL_MESG_VIEW' => 'ver toda la información / módulos de vtiger CRM',
      'LBL_MESG_EDIT' => 'editar toda la información / módulos de vtiger CRM',
      'LBL_TAB_MESG_OPTION' => 'módulos para mostrar',
      'LBL_CREATE_EDIT' => 'Crear/Editar',
      'LBL_VIEW' => 'Ver',
      'LBL_MANDATORY_MSG' => 'Campos Obligatorios',
      'LBL_DISABLE_FIELD_MSG' => 'Campos deshabilitados en configuración de acceso a campos globales',
      'LBL_DELETE' => 'Borrar',
      'LBL_STEP_2_2' => 'Paso 2 de 2',
      'LBL_FINISH_BUTTON' => 'Terminar',
      'LBL_NEW_GROUP' => 'Nuevo Grupo',
      'LBL_GROUPS' => 'Grupos',
      'LBL_GROUP_NAME' => 'Nombre de Grupo',
      'LBL_ROLES_SUBORDINATES' => 'Roles y Subordinados',
      'LBL_MEMBER_AVLBL' => 'Entidades y Miembros disponibles',
      'LBL_MEMBER_SELECTED' => 'Miembros seleccionados',
      'LBL_ENTITY' => 'Entidad',
      'LBL_OF' => 'de',
      'LBL_CREATE_NEW_GROUP' => 'Crear Grupo Nuevo',
      'LBL_ADD_GROUP_BUTTON' => 'Añadir Grupo',
      'LBL_GROUP_MESG1' => 'Los grupos son una forma flexible de asignar privilegios de acceso, cuando hay que definir priviliegios de acceso complicados. Puedes combinar múltimples entidades como Roles, Usuarios, perfiles, etc en un único grupo.',
      'LBL_GROUP_MESG2' => 'Para añadir, seleccione los miembros de la entidad de la izquierda y pulse el botón ">>"',
      'LBL_GROUP_MESG3' => 'Para eliminar, seleccione los miembros de la entidad de la derecha y pulse el botón "<<"',
      'LBL_GLOBAL_ACCESS_PRIVILEGES' => 'Privilegios de Acceso Globales',
      'LBL_RECALCULATE_BUTTON' => 'Recalcular',
      'LBL_CHANGE' => 'Cambiar',
      'LBL_PRIVILEGES' => 'Privilegios',
      'LBL_CUSTOM_ACCESS_PRIVILEGES' => 'Privilegios de Acceso Personalizados',
      'LBL_ADD_PRIVILEGES_BUTTON' => 'Añadir Privilegios',
      'LBL_RULE_NO' => 'Regla No.',
      'LBL_CAN_BE_ACCESSED' => 'puede acceder',
      'LBL_CUSTOM_ACCESS_MESG' => 'No hay reglas personalizadas de acceso definidas.',
      'LNK_CLICK_HERE' => 'Pulse aquí',
      'LBL_CREATE_RULE_MESG' => 'para crear nueva regla',
      'LBL_RECALC_MSG' => '¿Seguro que quiere Modificar los accesos compartidos?',
      'LBL_YES' => 'Si',
      'LBL_NO' => 'No',
      'LBL_IN_PERMISSION' => 'en los permisos',
      'LBL_RELATED_MODULE_RIGHTS' => 'Privilegios de Módulos Relacionados',
      'LBL_USR_CAN_ACCESS' => 'Usuarios pueden ',
      'LBL_USR_OTHERS' => ' otros usuarios ',
      'LBL_USR_CANNOT_ACCESS' => 'Usuarios no pueden acceder a otros usuarios ',
      'LBL_ORG_SHARING_PRIVILEGES' => 'Privilegios compartidos con la Organización',
      'LBL_EDIT_PERMISSIONS' => 'Editar Permisos',
      'LBL_SAVE_PERMISSIONS' => 'Guardar Permisos',
      'LBL_READ_ONLY' => 'Público: Sólo Lectura',
      'LBL_EDIT_CREATE_ONLY' => 'Público: Lectura, Crear/Editar',
      'LBL_READ_CREATE_EDIT_DEL' => 'Público: Lectura, Crear/Editar, Borrar',
      'LBL_PRIVATE' => 'Privado',
      'Public: Read Only' => 'Público: Sólo Lectura',
      'Public: Read, Create/Edit' => 'Público: Lectura, Crear/Editar',
      'Public: Read, Create/Edit, Delete' => 'Público: Lectura, Crear/Editar, Borrar',
      'Private' => 'Privado',
      'Hide Details' => 'Ocultar Detalles',
      'Hide Details and Add Events' => 'Ocultar Detalles y Añadir Eventos',
      'Show Details' => 'Mostrar Detales',
      'Show Details and Add Events' => 'Mostrar Detalles y Añadir Eventos',
      'LBL_LOGIN_HISTORY' => 'Histórico de Accesos',
      'Read/Write' => 'Leer/Escribir',
      'Read Only ' => 'Sólo Lectura ',
      'LBL_GROUP' => 'Grupo',
      'LBL_ACCESS_RIGHTS_FOR_MODULES' => 'Privilegios de Aceso para módulos relacionados',
      'LBL_ADD_RULE' => 'Añadir Regla',
      'LBL_ADD_CUSTOM_RULE' => 'Añadir Regla de Privilegios Personalizada',
      'LBL_RULE_CONSTRUCTION' => 'Muestra de Construcción de Reglas',
      'LBL_STEP' => 'Paso',
      'LBL_SELECT_ENTITY' => 'Selecciona una entidad de abajo',
      'LBL_CAN_BE_ACCESSED_BY' => 'Pueden acceder...',
      'LBL_PERMISSIONS' => 'Permisos',
      'LBL_DOC_MSWORD' => 'El Archivo ha de ser un documento .doc/msword',
      //'LBL_DOC_MSWORD' => 'El Archivo ha de ser un documento Microsoft Word/doc, OpenOffice/odt o Rich Text Format/rtf',
      'LBL_NODOC' => 'No hay archivos .doc en el directorio. Pruebe de nuevo.',
      'LOGO_ERROR' => 'El logotipo debe ser un archivo tipo .jpg /. png',
      'Error_Message' => 'Mensaje de Error',
      'Invalid_file' => 'Archivo erróneo o',
      'File_has_no_data' => 'El Archivo no tiene datos',
      'Sorry' => 'Lo Siento',
      'uploaded_file_exceeds_maximum_limit' => 'el archivo subido excede el máximo permitido.',
      'try_file_smaller' => 'Pruebe con un archivo más pequeño de 800000 bytes',
      'Problems_in_upload' => 'Problemas al subir el archivo',
      'Please_try_again' => 'Inténtelo de nuevo',
      'LBL_TESTMAILSTATUS' => 'Estado de Correo',
      'LBL_CHECK_ASSIGNEDTO_MAILID' => 'Compruebe el emailid asignado',
      'LBL_MAILSENDERROR' => 'El correo no se puede enviar al administrador. Compruebe su Id',
      'LBL_RECORD_NOEXIST' => 'Registro no encontrado',
      'LBL_ENTER_PROFILE' => 'Introduzca el nombre del Perfil',
      'LBL_DISABLE' => 'Desactivar',
      'LBL_PROXY' => 'proxy',
      'LBL_FIELDS_TO_BE_SHOWN' => 'Campos para mostrar',
      'SPECIFY_FILE_TO_MERGE' => 'Indique un archivo para combinar',
      'FILESIZE_EXCEEDS_INFO_CONFIG_INC' => '',
      'FILESIZE_EXCEEDS_INFO_PHP_INI' => 'Lo siento, el fichero cargado excede el tamaño máximo permitido por la configuracion en php.ini. Por favor intenta con un fichero más pequeño o modifique la configuración',
      'PROBLEMS_IN_FILEUPLOAD' => 'Problemas al subir el archivo. Inténtelo de nuevo.',
      'LBL_CUSTOMIZE_INVOICE_NUMBER' => 'Personalizar Nº de Factura',
      'LBL_CUSTOMIZE_INVOICE_NUMBER_DESCRIPTION' => 'Personalización de Nº de Factura',
      'LBL_CUSTOM_INVOICE_NUMBER_VIEW' => 'Personalización de Nº de Factura',
      'LBL_CUSTOMINVOICE_STRING' => 'Cadena de Factura Personalizada',
      'LBL_CUSTOMINVOICE_NUMBER' => 'Nº de Factura Personalizada',
      'LBL_INVOICE_NUMBER_PREVIEW' => 'Vista Previa',
      'LBL_INVOICE_NUMBER_BUTTON' => 'Actualizar Nº de Factura',
      'LBL_PROXY_AUTHENTICATION_REQUIRED' => 'Autentificación de Proxy Requerida',
      'LBL_ENABLE_FTP' => 'Debe tener Activado el soporte de FTP en php',
      'LBL_ADD_ROLE' => 'Añadir Rol',
      'LBL_EDIT_ROLE' => 'Editar Rol',
      'LBL_MOVE_ROLE' => 'Mover Rol',
      'LBL_BACKUP_DESC' => ' El CRM admite copias de seguridad sobre un servidor FTP. El CRM hará una copia de seguidad cada vez que un administrador se desconecte. Asegúrese de tener suficiente espacio en el servidor de FTP. La copia de seguidad tendrá el siguiente formato:: "backup_fecha_hora.sql".',
      'LBL_SUPPORT_NOTICIATION' => 'Fin de Soporte',
      'LBL_SUPPORT_NOTICIATION_MONTH' => 'Notificar Fin de Soporte el mes anterior',
      'LBL_SUPPORT_DESCRIPTION' => 'Notifica que finaliza el periodo de soporte contratado',
      'LBL_SUPPORT_DESCRIPTION_MONTH' => 'Notificar el Vencimiento del Soporte un mes antes del Vencimiento',
      'LBL_SELECT_ROLE' => 'Seleccionar Rol',
      'LBL_TEMPLATE' => 'Plantilla',
      'LBL_SELECT_EMAIL_TEMPLATE_FOR' => 'Seleccionar Plantilla de Email para',
      'ERR_CUSTOM_FIELD_WITH_NAME' => 'Un campo personalizado de nombre ',
      'ERR_ALREADY_EXISTS' => 'ya existe.',
      'ERR_SPECIFY_DIFFERENT_LABEL' => 'Por favor introduzca una etiqueta distinta',
      'LBL_TOOLS_TO_BE_SHOWN'=>'Herramientas a mostrar',
      'LBL_PICKLIST_GLOBAL_CHANGE'=>'Cambio Global',
      'LBL_PICKLIST_TRANSFER'=>'Transfiriendo los valores de ',
      'LBL_REPLACE_VALUE_WITH'=>'Sustituir valor con ',
      'LBL_EDIT_CUSTOM_RULE'=>'Editar Regla de Privilegio Personalizada',
      /*for global add/delete in picklist*/
      'DELETE_PICKLIST_VALUES'=>'Eliminar Valores de la Lista',
      'EDIT_PICKLIST_VALUE'=>'Editar Valores de la Lista',
      'ADD_PICKLIST_VALUES'=>'Añadir Valores de la Lista',
      'LBL_PICKLIST_ADDINFO'=>'Introduzca los valores uno a uno a continuación',
      'LBL_SELECT_ROLES'=> 'Selecciona el Rol que ha de ver los valores',
      'LBL_EXISTING_PICKLIST_VALUES'=>'Valores actuales de la Lista',
      'LBL_SELECT_PICKLIST'=>'Selecciona lista desplegable',

      'LBL_LANGUAGES' => 'Editar Paquete de idioma',
      'LBL_LANGUAGES_DESCRIPTION' => 'Gestionar Paquetes de Idiomas',

      // Added after 5.0.4 GA
      
      'LBL_GENERAL_FIELDS'=>'Campos Generales',
      
      'LBL_CANCEL_BUTTON'=>'Cancelar',
      
      //Added fields for Inventory Number labels
      'LBL_CUSTOMIZE_INVENTORY_NUMBER'=>'Personalizar Secuencia de Inventario',
      'LBL_CUSTOMIZE_INVENTORY_NUMBER_DESCRIPTION'=>'Personalización de la Secuencia de Inventario',
      'LBL_CUSTOM_QUOTE_NUMBER_VIEW'=>'Personalizar Nº de Presupuesto',
      'LBL_CUSTOMQUOTE_STRING'=>'Cadena Personalizada de Presupuesto',
      'LBL_CUSTOMQUOTE_NUMBER'=>'Número Personalizado de Presupuesto',
      'LBL_QUOTE_NUMBER_PREVIEW'=>'Previsualizar',
      'LBL_QUOTE_NUMBER_BUTTON'=>'Actualizar Nº de Presupuesto',
      'LBL_CUSTOM_SO_NUMBER_VIEW'=>'Personalizar Nº de Pedido',
      'LBL_CUSTOMSO_STRING'=>'Cadena Personalizada de Pedido',
      'LBL_CUSTOMSO_NUMBER'=>'Número Personalizado de Pedido',
      'LBL_SO_NUMBER_PREVIEW'=>'Previsualizar',
      'LBL_SO_NUMBER_BUTTON'=>'Actualizar Nº de Pedido',
      'LBL_CUSTOM_PO_NUMBER_VIEW'=>'Personalizar Nº de Orden Compra',
      'LBL_CUSTOMPO_STRING'=>'Cadena Personalizada de Orden Compra',
      'LBL_CUSTOMPO_NUMBER'=>'Número Personalizado de Orden Compra',
      'LBL_PO_NUMBER_PREVIEW'=>'Previsualizar',
      'LBL_PO_NUMBER_BUTTON'=>'Actualizar Nº de Orden Compra',
      
      // Added for Multi-Currency Support
      'LBL_TRANSFER_CURRENCY'=>'Moneda de Cambio',
      'LBL_CURRENT_CURRENCY'=>'Moneda Actual',
      
      //Added for new backup labels
      'LBL_LOCAL'=>'Local',
      'LBL_BACKUP'=>'Copia Seguridad',
      'LBL_BACKUP_LOCATION'=>'Ubicación Copia',
      'LBL_LAYOUT_EDITOR'=>'Editor de Disposición',
      'LBL_LAYOUT_EDITOR_DESCRIPTION'=>'Diseñar y modificar la disposición en cada uno de los módulos',
      'LBL_Show'=>'Mostrar',
      'LBL_Hide'=>'Esconder',

      // vtlib customization: Language Stings
      'VTLIB_LBL_MODULE_MANAGER'=>'Administrador de Módulos',
      'VTLIB_LBL_MODULE_MANAGER_DESCRIPTION'=>'Administrar el comportamiento del módulo dentro de vtiger CRM',
      'VTLIB_LBL_MODULE_MANAGER_CUSTOMMOD'=>'Módulos Personalizados',
      'VTLIB_LBL_MODULE_MANAGER_STANDARDMOD'=>'Módulos Estándar',
      'VTLIB_LBL_MODULE_MANAGER_NOMODULES'=>'No se han encontrado módulos personalizados! Crea o Importa uno nuevo...',

      // vtmailscanner START
      'LBL_MAIL_SCANNER'=>'Clasificar Correos',
      'LBL_MAIL_SCANNER_DESCRIPTION'=>'Configura el buzón para clasificación',
      'LBL_SCAN_NOW'=>'Clasifica Ahora',
      'LBL_RULE'=>'Regla',
      'LBL_SETUP'=>'Configura',
      'LBL_CONFIGURE'=>'Configura',
      'LBL_MAILBOX' => 'Buzón',
      'LBL_INFORMATION' => 'Información',
      'LBL_SCANNER' => 'Clasificador',
      'LBL_SERVER'  => 'Servidor',
      'LBL_PROTOCOL'=> 'Protocolo',
      'LBL_PASSWORD'=> 'Contraseña',
      'LBL_TYPE' => 'Tipo',
      'LBL_SSL' => 'SSL',
      'LBL_METHOD'=> 'Método',
      'LBL_VAL_SSL_CERT'=>'Validar Certificado SSL',
      'LBL_DONOT_VAL_SSL_CERT'=>'No Validar Certificado SSL',
      'LBL_STATUS'=>'Estado',
      'LBL_ENABLE'=>'Habilita',
      'LBL_DISABLE'=>'Deshabilita',
      'LBL_CONNECT'=>'Conecta',
      'LBL_URL_CAPS'=>'URL',
      'LBL_ENABLED'=>'Habilitado',
      'LBL_DISABLED'=>'Deshabilitado',
      'LBL_RULES'=>'Reglas',
      'LBL_FOR'=>'Para',
    
      'LBL_FROM'=>'De',
      'LBL_TO'=>'A',
    
      'LBL_ACTION'=>'Acción',
      'LBL_CREATE'=>'Crear',
      'LBL_TICKET'=>'Ticket',
      'LBL_ADD'=>'Añadir',
    
      'LBL_CONTACT'=>'Contacto',
      'LBL_ACCOUNT'=>'Cuenta',
    
      'LBL_FROM_CAPS'=>'DE',
      'LBL_TO_CAPS'=>'A',
      'LBL_TO_SMALL'=>'a',
    
      'LBL_CONTAINS'=>'Contiene',
      'LBL_EQUALS'=>'Igual a',
    
      'LBL_BEGINS'=>'Empieza',
    
      'LBL_REGEX'=>'Regex',
      'LBL_ENDS'=>'Termina con',
      'LBL_BODY'=>'Cuerpo',
    
      'LBL_NOT'=>'No',

      'LBL_ALL' => 'Toda',
      'LBL_ANY'=>'Cualquier',
      'LBL_CONDITION'=>'Condición',
      'LBL_ACTION'=>'Acción',
      'LBL_MOVE'=>'Mover',
      'LBL_UP'=>'Arriba',
      'LBL_DOWN'=>'Abajo',
      'LBL_PRIORITY'=>'Prioridad',
      'LBL_UPDATE'=>'Actualiza',
      'LBL_SELECT'=>'Selecciona',
      'LBL_FOLDERS'=>'Carpetas',
      'LBL_UNSELECT'=>'Des-selecciona',
      'LBL_MATCH'=>'Emparejar',
      'LBL_SCANNING'=>'Scaneando',
      'LBL_LOOKFOR'=>'Buscar',
      'LBL_UNREAD'=>'No leídos',
      'LBL_READ'=>'Leídos',
      'LBL_AFTER_SCAN'=>'Post-scan',
      'LBL_MESSAGES_FROM_LASTSCAN'=>'Mensajes último scan',
      'LBL_MARK_MESSAGE_AS'=>'Marcar mensaje como',

      //Added for the workflow module
      'LBL_LIST_WORKFLOWS'=>'Flujos de trabajo',
      'LBL_LIST_WORKFLOWS_DESCRIPTION' => 'Crear/Editar flujos de trabajo en vtiger CRM',
      'LBL_TASK_TITLE'=>'Tarea',
      'LBL_PARENT_WORKFLOW'=>'Flujo de trabajo superior',
      'MSG_EXECUTE_TASK_DELAY'=>'Ejecuta la tarea después de una espera',
      'LBL_AFTER'=>'Después',
      'LBL_BEFORE'=>'Antes',
      'LBL_TASK_OPERATIONS'=>'Operaciones de la Tarea',
      'LBL_CREATE_TASK'=>'Crear Tarea',
      'LBL_CREATE_TASK_OF_TYPE'=>'Crear una nueva tarea de tipo',
      'LBL_SUMMARY'=>'Resumen',
      'LBL_WHEN_TO_RUN_WORKFLOW'=>'Cuando ejecutar el flujo de trabajo',
      'LBL_ONLY_ON_FIRST_SAVE'=>'Solo al crear',
      'LBL_UNTIL_FIRST_TIME_CONDITION_TRUE'=>'Solo la primera vez que se cumple la condición',
      'LBL_EVERYTIME_RECORD_SAVED'=>'Cada vez que se guarda la entidad',
      'LBL_ON_MODIFY' => 'Cada vez que se modifica la entidad',
      'LBL_CONDITIONS'=>'Condiciones',
      'LBL_NEW_CONDITION_BUTTON_LABEL'=>'Nueva Condición',
      'LBL_TASKS'=>'Tareas',
      'LBL_NEW_TASK_BUTTON_LABEL'=>'Nueva Tarea',
      'LBL_TASK'=>'Tarea',
      // END

      //Added for vantage customization (Mandatory fields) -- Pavani
      'LBL_MANDATORY_FIELDS'=>'Campos obligatorios',
      'LBL_MANDATORY_FIELDS_DESCRIPTION'=>'Administrar campos obligatorios en todos los módulos',
      // Module Sequence Numbering
      'LBL_CUSTOMIZE_MODENT_NUMBER'=>'Personaliza Numeración Registro',
      'LBL_CUSTOMIZE_MODENT_NUMBER_DESCRIPTION'=>'Personalización Número de Entidad',
      // END

      //added for softphone integration
      'LBL_SOFTPHONE_SERVER_SETTINGS'=>'Configuración Servidor Telefonía IP',
      'LBL_SOFTPHONE_SERVER_SETTINGS_DESCRIPTION'=>'Configura tu teléfono IP aquí',
      'ASTERISK_SERVER_IP'=>'IP servidor Asterisk ',
      'ASTERISK_PORT'=>'Puerto servidor Asterisk',
      'ASTERISK_USERNAME'=>'Usuario Asterisk',
      'ASTERISK_PASSWORD'=>'Contraseña Asterisk',
      'ASTERISK_SERVER_IP_TITLE'=>'URL del servidor Asterisk',
      'ASTERISK_PORT_TITLE'=>'Puerto del API del administrador de llamadas asterisk (por defecto 5038)',
      'ASTERISK_USERNAME_TITLE'=>'Nombre de usuario en servidor Asterisk (normalmente el usuario administrador)',
      'ASTERISK_PASSWORD_TITLE'=>'Contraseña del usuario Asterisk',
      'LBL_CANCEL_BUTTON'=>'Cancelar',
      'ASTERISK_VERSION' => 'Versión Asterisk',
      'ASTERISK_VERSION_TITLE'=>'Selecciona tu versión de Asterisk; dejalo en la versión 1.4 si no estas seguro',
      'ASTERISK_CONFIGURATION'=>'Configuración Asterisk',
      //softphone integration ends

      'VTLIB_LBL_SELECT_PACKAGE_FILE'=>'Selecciona el Módulo Empaquetado',
      'VTLIB_LBL_FILE_LOCATION'=>'Ubicación fichero:',
      'VTLIB_LBL_PACKAGE_FILE_HELP'=>'el módulo vtiger se empaqueta como un fichero zip.',
      'VTLIB_LBL_IMPORT_FAILURE'=>'Error al importar',
      'VTLIB_LBL_INVALID_FILE'=>'Fichero de módulo inválido',
      'VTLIB_LBL_INVALID_IMPORT_TRY_AGAIN'=>'proporcionado para importar! Inténtalo de nuevo.',
      'VTLIB_LBL_UNABLE_TO_UPLOAD'=>'No se ha podido cargar',
      'VTLIB_LBL_UNABLE_TO_UPLOAD2'=>'el paquete al servidor! Inténtalo de nuevo.',
      'VTLIB_LBL_VERIFY_IMPORT_DETAILS'=>'Verifica los Detalles de Importación',
      'VTLIB_LBL_MODULE_NAME'=>'Nombre Módulo',
      'VTLIB_LBL_MODULE_DIR'=>'Directorio Módulo',
      'VTLIB_LBL_REQ_VTIGER_VERSION'=>'Versión de vtiger Requerida',
      'VTLIB_LBL_LICENSE'=>'Licencia',
      'VTLIB_LBL_LICENSE_ACCEPT_AGREEMENT'=>'Acepto el acuerdo de licencia.',
      'VTLIB_LBL_PROCEED_WITH_IMPORT'=>'¿Quieres seguir con el proceso de importación?',
      'VTLIB_LBL_IMPORTING_MODULE_START'=>'Importando Módulo ...',
      'VTLIB_LBL_WARNING'=>'Aviso',
      'VTLIB_LBL_NOT_WRITEABLE'=>'no escribible',
      'VTLIB_LBL_PACKAGE_VERSION'=>'Versión',
    
      'LBL_UPGRADE'=>'Actualizar',
      'VTLIB_LBL_UPDATE_FAILURE'=>'Actualización Falida',
      'VTLIB_LBL_MODULENAME_MISMATCH'=>'Nombres de módulos no coinciden',
      'VTLIB_LBL_TRY_AGAIN'=>'Inténtalo de nuevo',
      'VTLIB_LBL_VERIFY_UPDATE_DETAILS'=>'Verifica la información de actualización',
      'VTLIB_LBL_PROCEED_WITH_UPDATE'=>'¿Quieres continuar con la actualización?',
      'VTLIB_LBL_UPDAING_MODULE_START'=>'Actualizando el módulo...',
      'VTLIB_LBL_EXISTS'=>'Existe',
      'VTLIB_LBL_NOT_PRESENT'=>'No Presente',
      'VTLIB_LBL_INST_VERSION'=>'Versión Instalada',
      'VTLIB_LBL_MATCHES_PACKAGE_VERSION'=>'coincide con Versión empaquetada',
      'VTLIB_LBL_CANNOT_UPGRADE'=>'No se puede actualizar!',
      // END
    
      //User group fixes
      'LBL_USERNAME_EXIST' => 'Ya existe un usuario con ese nombre!',
      'LBL_GROUPNAME_EXIST' => 'Ya existe un grupo con ese nombre!',
      'LBL_ROLENAME_EXIST' => 'Ya existe un rol con ese nombre!',

      //layout editor
      'LBL_MOVE_FIELDS' => 'Mover campos',
      'NO_HIDDEN_FIELDS' => 'Sin campos ocultos',
      'LBL_RELATED_LIST' => 'Lista Relacionada',
      'LBL_ADD_BLOCK' => 'Añadir Bloque',
      'HIDDEN_FIELDS' => 'Campos Ocultos',
      'DOWN'=> 'Abajo',
      'UP'=> 'Arriba',
      'RIGHT' => 'Derecha',
      'LEFT' => 'Izquierda',
      'LBL_EDIT_PROPERTIES' => 'Editar Propiedades',
      'LBL_MANDATORY_FIELD' => 'Campo Obligatorio',
      'LBL_ACTIVE' => 'Activo',
      'LBL_QUICK_CREATE' => 'Creación Rápida',
      'LBL_MASS_EDIT' => 'Edición Masiva',
      'LBL_BLOCK_NAME' => 'Nombre Bloque',
      'AFTER' => 'Después',
      'ADD_BLOCK' => 'Añadir Bloque',
      'ARRANGE_RELATEDLIST' => 'Organizar Lista Relacionada',
      'CUSTOMFIELD_MAPPING' => 'Vinculación Campos Personalizados',
      'LBL_MAPPED_FIELDS' => 'Campos Vinculados',
      'LEADS_CUSTOM_FIELD_MAPPING_DESCRIPTION' => 'Vincula campos de Precontactos con Cuentas, Contactos y Potenciales',
      'LEADS_CUSTOM_FIELD_MAPPING'=> 'Vinculación Campos de Precontactos',
      'LBL_CALENDER_CUSTOMFIELDS' => 'Campos Personalizados Calendario',
      'LBL_CALENDER_CUSTOMFIELDS_DESCRIPTION' => 'Crear Campos Personalizados para el Calendario',
      'LBL_GO_BACK'=>'Atrás',

      //Added fix for: 5418
      'LBL_USE_PREFIX' => 'Utilizar Prefijo',
      'LBL_START_SEQ' => 'Iniciar Secuencia',
      'LBL_MODULE_NUMBERING' => 'Numeración Módulo',
      'LBL_FAILED' => 'Error',
      'LBL_DONE' => 'Hecho',
      'LBL_IN_USE' => 'EN USO',
      'LBL_MODULE_NUMBERING_FIX_MISSING' => 'Actualizar secuencia errónea ahora',

      //Added for: 5473
      'LBL_SHARING_ACCESS_HELPNOTE' => 'Trás las modificaciones, pulsa el botón de Recalcular para aplicar los cambios.',

      //for customer portal extension module
      'PORTAL_EXTENSION_DESCRIPTION'=>'Permite Configurar la Extensión Portal del Cliente',
      'LBL_CUSTOMER_PORTAL'=> 'Portal Cliente',

      'LBL_ADD_CUSTOMFIELD' => 'Añadir Campo Personalizado',

      'ERR_INVALID_PROFILE_ID' => 'Identificador perfil inválido. Por favor, indica un identificador válido',

      // Customization
      'LBL_PUBLISHER' => 'Publicado por',
      'LBL_PUBLISHED_ON' => 'Publicado el',
      'LBL_LICENSE'   => 'Licencia',
      'LBL_EXTENSION_FILE_DOWNLOAD_FAILED' => 'No se ha podido descargar la extensión!',
      'LBL_DEFAULT'=>'Por defecto, el servidor de correo saliente SMTP es od1.vtiger.com. Para evitar problemas, recomendamos que utilices una de estas opciones.',
      'LBL_OPTIONS1'=>'Enviar emails desde tu servidor de correo<br>
      				- Introducir la configuración (Servidor, Usuario, Contraseña) de la misma cuenta de correo utilizada en la cuenta de respuesta.',
      'LBL_OPTIONS2'=>"Añadir el servidor od1.vtiger.com como dominio autorizado desde tu dominio.<br>
      				- Si prefieres mantener el servidor saliente de vtiger, recomendamos que configures el registro SPF de tu dominio para incluir el servidor de vtiger como servidor autorizado.
      				  Para obtener instrucciones adicionales sobre cómo definir un registro SPF, contact con od-support@vtiger.com .",
      'LBL_ALREADY_EXISTS' => 'Ya Existe',
      'LBL_EXTENSION_INCOMPATIBLE' => 'Extensión Incompatible',
      'LBL_INSTALL' => 'Instalar',
      'LBL_DEFAULT_SETTINGS_BUTTON_TITLE' => 'Reestablecer al Defecto',
      'LBL_CONFIRM_DEFAULT_SETTINGS' => '¿Estás seguro que quieres cambiar los valores del servidor a sus valores por defecto?',
      'EXISTING_DEFAULT_VALUES' => 'Los valores del servidor ya están en sus valores por defecto',
      'LBL_NOTE' => 'Nota:',
      'LBL_HIDE' => 'Esconder Detalles',
      'LBL_SHOW' => 'Mostrar Detalles',
      // END
      'LBL_USER_ADDITION_INFO'=>"Para añadir un nuevo usuario, haz click en  
      			   <span style='font-style:italic;color:blue;'>OD-Menú Configuración -> On Demand Admin -> Añadir / Invitar Usuario </span>",
      
      'LBL_READ_ONLY_ACCESS_MSG' => 'Acceso Solo-Lectura',
      'LBL_READ_WRITE_ACCESS_MSG' => 'Acceso Lectura-Escritura',
      'LBL_DESCRIPTION_Public: Read Only'=>'Usuarios pueden Solo Leer otros usuarios ',
      'LBL_DESCRIPTION_Public: Read, Create/Edit'=>'Usuarios pueden Leer, Crear/Editar otros usuarios ',
      'LBL_DESCRIPTION_Public: Read, Create/Edit, Delete'=>'Usuarios pueden Leer, Crear/Editar, Eliminar otros usuarios ',

      'LBL_DEFAULT_VALUE' => 'Valor por Defecto',

      // For Dependency picklist
      'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Configuración Dependencias entre Listas',
      'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Establece Dependencias entre los elementos de las listas desplegables en cada módulo',

      'Settings' => 'Configuración',
      'LBL_ERR_TAX_LABEL_ALREADY_EXISTS' => 'Este impuesto ya existe.',
      'LBL_ERR_SOME_TAX_LABELS_ALREADY_EXISTS' => 'Algunos impuestos tienen el nombre repetido y no han sido guardados.',
      'LBL_EDIT_COMPANY_INFO' => "Para editar la información de la empresa, haz click sobre
                          <span style='font-style:italic;color:blue;'>Icono Configuración > Administrador > Empresa </span>",

      'Configuration Editor'=>'Editor de Configuración',

      'ModTracker' => 'Control de Cambios',
      'LBL_MODTRACKER_DESCRIPTION' => 'Selecciona módulos para seguimiento',

      'LBL_MENUS_TO_SHOW'=>'Selecciona módulos a mostrar en menú principal',
      'LBL_MENU_DESC'=>'Personalizar Secuencia de Menú',
      'LBL_MENU_EDITOR'=>'Editor de Menú',
      'LBL_MENUS_TO_SHOW_DESCRIPTION' => 'Utiliza las flechas para ordenar los elementos del menú. Los primeros 10 elementos aparecen en el menú, los demás se muestran en el desplegable <b><i>Más</i></b>',
      'LBL_ALL_MODULES' => 'Todos los Módulos',
      'LBL_SELECTED_MODULES' => 'Módulos Seleccionados',

      'LBL_CRM_SETTINGS' => 'Configuración CRM',

);
$mod_list_strings = array (
);
?>
